profile.nlreg.
It is not intended to be called directly by users.all.profiles.nlreg(fitted, hoa = TRUE, precision = 6, signif = 30,
n = 50, omit = 0.5, trace = FALSE, call, ...)nlreg object such as returned by a call to
nlreg.TRUE.precision*s.e., that
are profiled. The default is 6.omit*s.e., which is
omitted in the spline interpolation of the higher order statistics
considered. The purpose is to avoiTRUE, details of the iterations are printed.all.nlreg.profiles for profiling
all parameters of a nonlinear heteroscedastic model.all.profiles.nlreg function is called internally by the
profile.nlreg routine. It is not intended to
be called directly by users.profile.nlreg,
nlreg.profile.objects,
nlreg.object