Learn R Programming

hoa (version 2.1.2)

family.rsm.object: Family Object for Regression-Scale Models

Description

Class of objects that characterize the error distribution of a regression-scale model.

Arguments

Generation

This class of objects is returned by a call to a family.rsm generator function. See rsm.families for the distributions which are supported by the marg package. The object includes a list of functions and expressions that characterize the error distribution of a regression-scale model. These are used by the IRLS algorithm implemented in the rsm fitting routine. New families can be added to the ones already supported. See the demonstration file margdemo.R that ships with the package. There is a print method for family.rsm objects which produces a simple summary without any detail; use unclass(family.rsm.object) to see the contents.

See Also

rsm.families, family.rsm, rsm