Learn R Programming

hoa (version 2.1.2)

family.summary.cond: Use family() on a ``summary.cond'' object

Description

This is a method for the function family() for objects inheriting from class summary.cond. See family for the general behaviour of this function.

Usage

## S3 method for class 'summary.cond':
family(object, \dots)

Arguments

object
any object from which a family object can be extracted.
...
absorbs any additional argument.

See Also

family