Learn R Programming

hoa (version 2.1.2)

houses: House Price Data

Description

The houses data frame has 26 rows and 5 columns.

Ms. Terry Tasch of Long-Kogan Realty, Chicago, provides data on the selling prices of houses and on different variables describing their status. This data frame contains the prices and a subset of the covariates.

Usage

data(houses)

Arguments

source

The data were obtained from

Sen, A. and Srivastava, M. (1990) Regression Analysis: Theory, Methods and Applications (Exhibit 2.2, page 32). New York: Springer-Verlag.

Examples

Run this code
data(houses)
summary(houses)
pairs(houses)

Run the code above in your browser using DataLab