Learn R Programming

hoa (version 2.1.2)

print.family.rsm: Use print() on a ``family.rsm'' object

Description

This is a method for the function print() for objects inheriting from class family.rsm. See print or print.default for the general behaviour of this function.

Usage

## S3 method for class 'family.rsm':
print(x, \dots)

Arguments

Details

A family.rsm object is a list of functions and expressions. All that is printed is an identification label. To see the functions themselves, access the individual components, or use print.default() or unclass().

See Also

family.rsm.object, print, print.default

Examples

Run this code
student(df = 3) ## generates Student's t error distribution family
## 
## g  :  function (y, df, ...)  (df + 1)/2 * log(1 + y^2/df)
## g' :  function (y, df, ...)  (df + 1) * y/(df + y^2)
## g'':  function (y, df, ...)  (df + 1) * (df - y^2)/(df + y^2)^2
##
## df : 3
unclass(student(df = 3))
## $family
## [1] "student"
##
## $g0
## function(y,df,...)  (df+1)/2*log(1+y^2/df)
##
## $g1
## function(y,df,...)  (df+1)*y/(df+y^2)
##
## $g2
## function(y,df,...)  (df+1)*(df-y^2)/(df+y^2)^2
##
## $df
## [1] 3
##
## $k
## NULL

Run the code above in your browser using DataLab