This is a method for the function residuals() for objects
inheriting from class nlreg. It extracts the standardized
residuals from a nonlinear model fit. See residuals for
the general behavior of this function and for the interpretation of
object. A wider choice of residuals is available through the
nlreg.diag function.
# S3 method for nlreg
residuals(object, …)
# S3 method for nlreg
resid(object, …)