Fits a rsm model without computing the model matrix of the
response vector.
rsm.fit(X, Y, offset, family, dispersion, score.dispersion, maxit, epsilon,
trace, …)the model matrix (design matrix).
the response vector.
if NULL, the MLE of the scale parameter is returned,
otherwise the scale parameter is fixed to the numerical value
passed through the argument. If Huber's least favourable
distribution is used and dispersion is TRUE, the
MAD is computed and the scale parameter fixed to this
value in subsequent calculations.
must default to NULL.
optional offset added to the linear predictor.
a family.rsm object, i.e. a list of functions and
expressions characterizing the error distribution. Families
supported are gaussian, student (Student's t),
extreme (Gumbel or extreme value), logistic,
logWeibull, logExponential, logRayleigh and
Huber (Huber's least favourable). Users can construct their
own families, as long as they have components compatible with those
given in rsm.distributions. The demonstration file
margdemo.R that ships with the package shows how to
create a new generator function.
maximum number of iterations allowed.
convergence threshold.
if TRUE, iterations details are printed during execution.
not used, but do absorb any redundant argument.
an object which is a subset of a rsm object.
The rsm.fit function is called internally by the
rsm routine to do the actual model fitting. Although
it is not intended to be used directly by the user, it may be useful
when the same data frame is used over and over again. It might save
computational time, since the model matrix is not created. No
formula needs to be specified as an argument. As no weights
argument is available, the response Y and the model matrix
X must already include the weights if weighting is desired.