Learn R Programming

hoa (version 2.1.1)

all.profiles.nlreg: Support for function `profile.nlreg'

Description

This is support for the function profile.nlreg. It is not intended to be called directly by users.

Usage

## S3 method for class 'nlreg':
all.profiles(fitted, hoa = TRUE, precision = 6, signif = 30, 
                   n = 50, omit = 0.5, trace = FALSE, call, \dots)

Arguments

fitted
a fitted nlreg object such as returned by a call to nlreg.
hoa
logical value indicating whether higher order statistics should be calculated; default is TRUE.
precision
numerical value defining the maximum range of values, given by MLE $\pm$ precision*s.e., that are profiled. The default is 6.
signif
the maximum number of output points that are calculated exactly; default is 30.
n
the approximate number of output points produced by the spline interpolation; default is 50.
omit
numerical value defining the range of values, given by MLE $\pm$ omit*s.e., which is omitted in the spline interpolation of the higher order statistics considered. The purpose is to avoid n
trace
if TRUE, details of the iterations are printed.
...
absorbs any additional argument.

Value

  • a list of elements of class all.nlreg.profiles for profiling all parameters of a nonlinear heteroscedastic model.

Details

The all.profiles.nlreg function is called internally by the profile.nlreg routine. It is not intended to be called directly by users.

See Also

profile.nlreg, nlreg.profile.objects, nlreg.object