Ms. Terry Tasch of Long-Kogan Realty, Chicago, provides data on
the selling prices of houses and on different variables describing
their status. This data frame contains the prices and a subset
of the covariates.
Usage
data(houses)
Arguments
source
The data were obtained from
Sen, A. and Srivastava, M. (1990) Regression Analysis: Theory,
Methods and Applications (Exhibit 2.2, page 32). New York:
Springer-Verlag.