Learn R Programming

hoa (version 2.1.2)

residuals.nlreg: Use residuals() on a `nlreg' object

Description

This is a method for the function residuals() for objects inheriting from class nlreg. It extracts the standardized residuals from a nonlinear model fit. See residuals for the general behavior of this function and for the interpretation of object. A wider choice of residuals is available through the nlreg.diag function.

Usage

## S3 method for class 'nlreg':
residuals(object, \dots)
## S3 method for class 'nlreg':
resid(object, \dots)

Arguments

See Also

nlreg.object, nlreg.diag, residuals