rsm model without computing the model matrix of the
response vector.rsm.fit(X, Y, offset, family, dispersion, score.dispersion, maxit, epsilon,
trace, ...)NULL, the MLE of the scale parameter is returned,
otherwise the scale parameter is fixed to the numerical value
passed through the argument. If Huber's least favourable
distribution is used and dispNULL.family.rsm object, i.e. a list of functions and
expressions characterizing the error distribution. Families
supported are gaussian, student (Student's t),
extreme (Gumbel or extreme valTRUE, iterations details are printed during execution.rsm object.rsm.fit function is called internally by the
rsm routine to do the actual model fitting. Although
it is not intended to be used directly by the user, it may be useful
when the same data frame is used over and over again. It might save
computational time, since the model matrix is not created. No
formula needs to be specified as an argument. As no weights
argument is available, the response Y and the model matrix
X must already include the weights if weighting is desired.rsm, rsm.surv, rsm.null,
rsm.object, rsm.families